package logic

import (
	"context"
	"fusenapi/utils/auth"
	"fusenapi/utils/basic"

	"fusenapi/server/ldap-admin/internal/svc"
	"fusenapi/server/ldap-admin/internal/types"

	"github.com/zeromicro/go-zero/core/logx"
)

type GetDepartmentsLogic struct {
	logx.Logger
	ctx    context.Context
	svcCtx *svc.ServiceContext
}

func NewGetDepartmentsLogic(ctx context.Context, svcCtx *svc.ServiceContext) *GetDepartmentsLogic {
	return &GetDepartmentsLogic{
		Logger: logx.WithContext(ctx),
		ctx:    ctx,
		svcCtx: svcCtx,
	}
}

// 处理进入前逻辑w,r
// func (l *GetDepartmentsLogic) BeforeLogic(w http.ResponseWriter, r *http.Request) {
// }

func (l *GetDepartmentsLogic) GetDepartments(req *types.Request, userinfo *auth.UserInfo) (resp *basic.Response) {
	//todo 鉴权 。。。。
	departList,_,err := l.svcCtx.AllModels.LdapDepartment.GetAll(l.ctx,"")
	if err != nil{
		logx.Error(err)
		return resp.SetStatusWithMessage(basic.CodeDbSqlErr,"获取部门列表失败")
	}
	mapDepartment := make(map[int64]*types.DepartmentsItem)
	for _,v := range departList{
		mapDepartment[v.Id] = &types.DepartmentsItem{
			Id:        v.Id,
			Name:      *v.Name,
			Remark:    *v.Remark,
			Type:      *v.Type,
			ParentId:  *v.ParentId,
			Dn:        *v.Dn,
			SyncState: *v.SyncState,
			Child:     make([]*types.DepartmentsItem,0,50),
		}
	}
	//组织树形关系
	for _,v := range mapDepartment{
		//有父级，把他付给父级
		if info,ok := mapDepartment[v.ParentId];ok{
			info.Child = append(info.Child,v)
		}

	}
	list := make([]*types.DepartmentsItem,0,len(departList))
	for _,v := range mapDepartment{
		if v.ParentId == 0{
			list = append(list,v)
		}
	}
	return resp.SetStatusWithMessage(basic.CodeOK,"success",types.GetDepartmentsRsp{
		List: list,
	})
}

// 处理逻辑后 w,r 如:重定向, resp 必须重新处理
// func (l *GetDepartmentsLogic) AfterLogic(w http.ResponseWriter, r *http.Request, resp *basic.Response) {
// // httpx.OkJsonCtx(r.Context(), w, resp)
// }
